Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1954)

Unified Diff: components/html_viewer/ime_controller.h

Issue 1351013002: Revert of Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/html_widget.cc ('k') | components/html_viewer/ime_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/ime_controller.h
diff --git a/components/html_viewer/ime_controller.h b/components/html_viewer/ime_controller.h
index 24923ab2bdd2154e94b3b306abf11c2402c78a5d..8c2917fae20def7e255590a7963f31629d5c980c 100644
--- a/components/html_viewer/ime_controller.h
+++ b/components/html_viewer/ime_controller.h
@@ -12,7 +12,7 @@
class WebWidget;
}
-namespace mus {
+namespace mojo {
class View;
}
@@ -22,7 +22,7 @@
// handling IME related stuff.
class ImeController {
public:
- ImeController(mus::View* view, blink::WebWidget* widget);
+ ImeController(mojo::View* view, blink::WebWidget* widget);
~ImeController();
// Methods called by WebWidget overrides.
@@ -33,13 +33,13 @@
void ShowImeIfNeeded();
private:
// Update text input state from WebWidget to mus::View. If the focused
// element is editable and |show_ime| is True, the software keyboard will be
// shown.
void UpdateTextInputState(bool show_ime);
// Not owned objects.
- mus::View* view_;
+ mojo::View* view_;
blink::WebWidget* widget_;
blink::WebTextInputInfo text_input_info_;
« no previous file with comments | « components/html_viewer/html_widget.cc ('k') | components/html_viewer/ime_controller.cc » ('j') | no next file with comments »
@@ -33,13 +33,13 @@
void ShowImeIfNeeded();
private:
- // Update text input state from WebWidget to mus::View. If the focused
+ // Update text input state from WebWidget to mojo::View. If the focused
// element is editable and |show_ime| is True, the software keyboard will be
// shown.

Powered by Google App Engine
This is Rietveld 408576698